/*
  Copyright 2004 Tobias Eckert
  Copyright 2003 John Knottenbelt
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
*/

#include "config.h"
#include "tuneparams.h"
#include "stringutil.h"

#include <map>
#include <iostream>
#include <cstdlib>
#include "tune.h"

// DVB-S Tuning Parameters 

DVBSTuneParams::DVBSTuneParams(const std::string &name, int apid, int vpid)
  : TuneParams(name, apid, vpid),
    freq(0),
    sr(0),
    sat_no(0),
    pol(0)
{
}

DVBSTuneParams::~DVBSTuneParams()
{
}

DVBSTuneParams *DVBSTuneParams::createFromSZAP(const std::string &line)
{
  // It is assumed that the line is a valid SZAP conf line
  // (not a comment) 

  std::vector<std::string> v;
  splitString(line, ':', v);

  std::string newName = v[0];
  int vpid = toUnsignedLong(v[5]);
  int apid = toUnsignedLong(v[6]);

  DVBSTuneParams *p = new DVBSTuneParams(newName, vpid, apid);
  p->freq = toUnsignedLong(v[1]) * 1000;
  p->pol = ((v[2] == "h") ? 0 : 1);
  p->sat_no = toUnsignedLong(v[3]);
  p->sr = toUnsignedLong(v[4]) * 1000;

  return p;
}

bool DVBSTuneParams::tune(int frontendFD) const
{
  char polarity;
  polarity = ((pol == 0) ? 'h' : 'v');

  // Give it three goes at least!
  for (int i = 0; i < 3; i++) {
    int rc = tune_it(frontendFD, 
		     freq,       // frequency to tune to
		     sr,	// Symbol Rate for DVB-C or DVB-S 
		     polarity,	// Polarity 
		     -1,	// Tone  
		     fe_spectral_inversion_t(0), 
		     0,		// diseqc
		     fe_modulation_t(0),
		     fe_code_rate_t(0), 
		     fe_transmit_mode_t(0),
		     fe_guard_interval_t(0), 
		     fe_bandwidth_t(0),
		     fe_code_rate_t(0),
		     fe_hierarchy_t(0)
    );
    if (rc >= 0)
      return true;
  }

  std::cerr << "Fatal error: failed to tune channel " << name << "\n";
  return false;
}

bool DVBSTuneParams::sameAsExceptPIDs(const TuneParams &other) const
{
  const DVBSTuneParams &x = dynamic_cast<const DVBSTuneParams&>(other);

  if (&x == NULL)
    return false;
 
  return (freq == x.freq &&
          pol  == x.pol &&
	  sat_no == x.sat_no &&
	  sr == x.sr
  );
}
