/*
  Copyright 2003 John Knottenbelt
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
*/

#include "config.h"
#include "recordconnection.h"
#include "debug.h"
#include <iostream>

RecordConnection::RecordConnection(const Recording &rec, TunerManager *tm, int dataFD)
  : Connection(tm, dataFD), rec(rec)
{
}

bool RecordConnection::tune() {
  return Connection::tune(rec.getType(), rec.getChannel(), 
			  rec.getConvertToPS(), rec.getPriority());
}

void RecordConnection::addSelectFDs(Select &s) const
{
  Connection::addSelectFDs(s);

  if (getStopTime() != 0)
    s.addAlarm(std::max(0L, getStopTime() - getCurrentTime()), 0);
}

std::string RecordConnection::getType() const
{
  return "RecordConnection";
}

std::ostream& RecordConnection::printOn(std::ostream &o) const
{
  return Connection::printOn(o) << " " << rec;
}

bool RecordConnection::processReady(const Select &s)
{
  if (getStopTime() != 0 && getCurrentTime() > getStopTime()) {
    if (debugLevel > 0) {
      std::cerr << "Stop time reached (stopTime = " << getStopTime() 
		<< ", now = " << getCurrentTime() << ")\n";
    }
    return false;
  }

  return Connection::processReady(s);
}

